@@ -50,7 +50,7 @@ updateExplorePage <- function() {
 			tmp.aggr1 <- lapply(.(rawdata.call), aggregate.timeblob,
 				by=.(aggr1By)))
 		if (any(grep("( month|year)", aggr1By))) {
-			aggr.call[[3]]$start.month <- hsp$startMonth
+			aggr.call[[3]]$start.month <- hsp$yearStart
 		}
 		if (doSmooth) {
 			aggr.call <- bquote(
@@ -65,7 +65,7 @@ updateExplorePage <- function() {
 			tmp.aggr2 <- lapply(.(rawdata.call), aggregate.timeblob,
 				by=.(aggr2By)))
 		if (any(grep("( month|year)", aggr2By))) {
-			aggr.call[[3]]$start.month <- hsp$startMonth
+			aggr.call[[3]]$start.month <- hsp$yearStart
 		}
 		if (doSmooth) {
 			aggr.call <- bquote(
@@ -152,7 +152,7 @@ updateExplorePage <- function() {
 	}
 	
 	# plot scales and annotation specifications
-	plot.call$xscale <- quote(hsp$timePeriod)
+	plot.call$xlim <- quote(hsp$timePeriod)
 	plot.call$sameScales <- if (doCommonScale) { T } else { F }
 	plot.call$allSameScales <- if (doCommonScale && doSuperpose #&& !doSmooth
 		&& (length(list.call[-1]) > 1)) { T }
@@ -161,11 +161,11 @@ updateExplorePage <- function() {
 	}
 	
 	addToLog(paste(deparse(plot.call), collapse="\n"))
-	guiDo(playwith(plot.call=plot.call, name="timeseries", 
-		buttons=hydrosanityButtons[c('zoomin','zoomout','centre','logscale','setperiod')],
-		extra.buttons=NULL, 
-		eval.args="^hsp$", invert=T, restore.on.close=StateEnv$win), 
-		doLog=F)
+	playwith(plot.call=plot.call, title="timeseries", 
+		viewport="time.vp", time.mode=TRUE,
+		# TODO: log scale button
+		bottom=list(setPeriodTool),
+		eval.args="^hsp$", invert.match=T, on.close=restoreHS)
 	
 	if (length(tmpObjs) > 0) {
 		guiDo(call=bquote(rm(list=.(tmpObjs))))
@@ -221,18 +221,18 @@ updateExplorePage <- function() {
 			tmp.data <- lapply(tmp.data, aggregate.timeblob, by=.(aggrBy))
 		)
 		if (any(grep("( month|year)", aggrBy))) {
-			aggr.call[[3]]$start.month <- hsp$startMonth
+			aggr.call[[3]]$start.month <- hsp$yearStart
 		}
 		guiDo(call=aggr.call)
 	}
 	
 	# make.groups
-	tmpObjs <- c(tmpObjs, 'tmp.groups')
+	tmpObjs <- c(tmpObjs, "tmp.groups")
 	guiDo(string=sprintf(
-		'tmp.groups <- make.groups(%s)',
-		paste(sep='', collapse=', ',
+		"tmp.groups <- make.groups(%s)",
+		paste(sep="", collapse=", ",
 			make.names(names(tmp.data)), 
-			'=tmp.data[[', dQuote(names(tmp.data)), ']]$Data')
+			'=tmp.data[[', shQuote(names(tmp.data)), ']]$Data')
 	))
 	#guiDo(tmp.groups <- do.call(make.groups, 
 	#	lapply(tmp.data, function(x) x$Data )))
@@ -264,8 +264,8 @@ updateExplorePage <- function() {
 		tmpObjs <- c(tmpObjs, 'tmp.probs')
 		plot.call$scales <- quote(list())
 		if (doNormal) {
-			guiDo(tmp.probs <- c(0.001, 0.01, 0.1, 0.25, 0.5, 
-				0.75, 0.9, 0.99, 0.999))
+			guiDo(tmp.probs <- c(0.0001, 0.001, 0.01, 0.1, 0.25, 0.5, 
+				0.75, 0.9, 0.99, 0.999, 0.9999))
 			plot.call$scales$x <- quote(list(
 				at=qnorm(1-tmp.probs), labels=tmp.probs * 100))
 			plot.call$xlim <- quote(rev(extendrange(qnorm(tmp.probs))))
@@ -299,10 +299,9 @@ updateExplorePage <- function() {
 	}))
 	
 	addToLog(paste(deparse(plot.call), collapse="\n"))
-	guiDo(playwith(plot.call=plot.call, name="distribution", 
-		extra.buttons=list("logscale"), labels=idLabels, 
-		eval.args="^hsp$", invert=T, restore.on.close=StateEnv$win), 
-		doLog=F)
+	playwith(plot.call=plot.call, title="distribution", 
+		labels=idLabels, 
+		eval.args="^hsp$", invert.match=T, on.close=restoreHS)
 	
 	if (length(tmpObjs) > 0) {
 		guiDo(call=bquote(rm(list=.(tmpObjs))))
@@ -429,11 +428,9 @@ updateExplorePage <- function() {
 	idLabels <- rep(format(tmp.data$Time, "%Y"), nBlobs)
 	
 	addToLog(paste(deparse(plot.call), collapse="\n"))
-	guiDo(playwith(plot.call=plot.call, name="seasonality", 
-		extra.buttons=list("logscale"),
+	playwith(plot.call=plot.call, title="seasonality", 
 		labels=idLabels, 
-		eval.args="^hsp$", invert=T, restore.on.close=StateEnv$win), 
-		doLog=F)
+		eval.args="^hsp$", invert.match=T, on.close=restoreHS)
 	
 	if (length(tmpObjs) > 0) {
 		guiDo(call=bquote(rm(list=.(tmpObjs))))
